/*
 * sjabloon.h
 * note that /sja/ is easy to type, at least on qwertz ;-)
 */

#ifndef __sjabloon_h
#define __sjabloon_h

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>

#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <errno.h>

#ifdef DEBUG
#include <stdio.h>
#define debug(msg) fprintf(stderr,"DEBUG [%s]: %s\n",__FUNCTION__,msg);
#define debug_int(msg,val) fprintf(stderr,"DEBUG [%s]: %s:%d\n",__FUNCTION__,msg,val);
#define debug_ptr(msg,val) fprintf(stderr,"DEBUG [%s]: %s:%p (%dx)\n",__FUNCTION__,msg,val,(unsigned int)val);
#endif /* DEBUG */

#ifndef DEBUG
#define debug(msg)
#define debug_int(msg,val)
#define debug_ptr(msg,val)
#endif 

/*
 * size of the chunks of memory that will be allocated 
 * for sja->buf
 */
#define SJA_CHUNK_LEN 1

/*
 * makro for reallocating chunked space
 */
#define SJA_CHUNKED_SIZE(length) ((unsigned int)((length+1)/SJA_CHUNK_LEN)+1)*SJA_CHUNK_LEN

/*
 * this is a sjabloon
 */
typedef struct sja_t
	{
	char *buf;			// ptr to data
	unsigned int len;		// strlen(data) (excl. terminating NULL)
	unsigned int space;		// alloc'd space for data
	} sja_t;

/*
 * function definitions
 */

sja_t *sja_init_string(const char const *);
sja_t *sja_init_file(const char const *);

int sja_replace(sja_t *sja, const char const *, const char const *);
int sja_destroy(sja_t *);

static unsigned int sja_tokat(const sja_t *, const char const *, const unsigned int);

#endif /* __sjabloon_h */


